@@ -57,9 +57,12 @@ class SequentialPatternGenerator(Generator):
 		self.__chList = chList
 
 	def generate(self):
-		pick = self.__chList.pop(0)
-		output = self.__trySub(self.__pattern, "%s", pick)
-		return output
+		try:
+			pick = self.__chList.pop(0)
+			output = self.__trySub(self.__pattern, "%s", pick)
+			return output
+		except IndexError:
+			raise self.GeneratorOutOfItemsException
 	
 	def __trySub(self, istr, pattern, sub):
 		return istr.replace(pattern, str(sub))
@@ -123,6 +126,18 @@ class SetGenerator(Generator):
 			raise self.GeneratorOutOfItemsException
 
 
+class SequentialSetGenerator(Generator):
+	def __init__(self, chSet):
+		self.chSet = list(chSet)
+
+	def generate(self):
+		try:
+			pick = self.chSet.pop(0)
+			return pick
+		except IndexError:
+			raise self.GeneratorOutOfItemsException
+
+
 class FakeFirstNameGenerator(Generator):
 	def __init__(self):
 		self.__faker = Faker()
