@@ -1,4 +1,5 @@
 from .Column import *
+from .CSVReader import *
 
 class Table:
 	def __init__(self, name):
@@ -16,4 +17,9 @@ class Table:
 		for i in self.columns:
 			if i.pk:
 				return i.name
-		return ""
\ No newline at end of file
+		return ""
+
+	def fromCsv(self, filename):
+		csvreader = CSVReader(self)
+		csvreader.read(filename)
+		pass
\ No newline at end of file
